
# Type: functional association_object




URI: [biolink:functional_association_object](https://w3id.org/biolink/vocab/functional_association_object)


## Domain and Range

[FunctionalAssociation](FunctionalAssociation.md) ->  <sub>REQ</sub> [GeneOntologyClass](GeneOntologyClass.md)

## Parents

 *  is_a: [object](object.md)

## Children

 *  [gene to go term association➞object](gene_to_go_term_association_object.md)
 *  [macromolecular machine to biological process association➞object](macromolecular_machine_to_biological_process_association_object.md)
 *  [macromolecular machine to cellular component association➞object](macromolecular_machine_to_cellular_component_association_object.md)
 *  [macromolecular machine to molecular activity association➞object](macromolecular_machine_to_molecular_activity_association_object.md)

## Used by

 * [FunctionalAssociation](FunctionalAssociation.md)
